shared

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PackageSpec

type PackageSpec struct {
	Dir  string
	Path string
}

PackageSpec identifies a package by dir and path

type Setup

type Setup struct {
	Env            vos.Env
	Paths          *patsy.Cache
	Enforce        bool
	Verbose        bool
	Short          bool
	Timeout        string
	Load           string
	Output         string
	TestArgs       []string
	Packages       []PackageSpec
	PackageImports map[string]map[string]bool // map of package path to its direct imports
}

Setup holds globals, environment and command line flags for the courtney command

func (*Setup) Parse

func (s *Setup) Parse(args []string) error

Parse parses a slice of strings into the Packages slice

Jump to